==> maxdb-all-linux-64bit-x86_64-7_6_00_36.tgz: SAPDB/Install/Window/Banner.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_00/b_36/sys/src/install/perl/SAPDB/Install/Window/Banner.pm#1 $
# $DateTime: 2006/11/17 17:24:42 $
# $Change: 140017 $
#
# Desc: start SAP DB installation/update/patch/instanceupgrade, called by SDBINST/SDBUPD


package SAPDB::Install::Window::Banner;


use Wx::Event qw(EVT_SET_FOCUS);
use Wx qw( wxHORIZONTAL wxVERTICAL wxEXPAND wxLEFT
		   wxRIGHT wxALL wxBLACK wxALIGN_RIGHT
		   wxWHITE wxDECORATIVE wxNORMAL wxBOLD);

use	SAPDB::Install::Resources;
use	SAPDB::Install::Control::StaticText;	

#
#	should be base of Wx::PlWindow,
#	but it cannot "AutoLayout"
#	as workarround use SAPDB::Install::Helpers::PassiveWin here
#

use base SAPDB::Install::Helpers::PassiveWin;

sub new{
	my($this ) = shift->SUPER::new(@_);
	$this->SetBackgroundColour(wxWHITE);
	$this->{'topsizer'} = Wx::BoxSizer->new(wxHORIZONTAL);
	$self->{'img_sizer'} = Wx::BoxSizer->new(wxVERTICAL);
	my $rc = SAPDB::Install::Resources->new('RESOURCES.TGZ');
	my $imgs = $rc->getImages('banner/MaxDB1.png');
	$this->{'img'} = Wx::StaticBitmap->new($this,-1,Wx::Bitmap->new($imgs->{'banner/MaxDB1.png'}));
	$this->{'text_sizer'} = Wx::BoxSizer->new(wxVERTICAL);
	$this->{'title'} = SAPDB::Install::Control::StaticText->new($this,-1);
	$this->{'title'}->{'font'} = Wx::Font->new(18,$^O =~ /mswin/i ? wxNORMAL : wxDECORATIVE, wxNORMAL, wxBOLD, 0 );
	$this->{'title'}->{'text_colour'} = Wx::Colour->new(100,100,100);
	$this->{'subtitle'} = SAPDB::Install::Control::StaticText->new($this,-1);
	$this->{'subtitle'}->{'font'} = Wx::Font->new(10,wxNORMAL, wxNORMAL, wxBOLD, 0 );
	$this->{'subtitle'}->{'text_colour'} = Wx::Colour->new(100,100,100);
	$this->{'text_sizer'}->Add($this->{'title'});
	$this->{'text_sizer'}->Add($this->{'subtitle'});
	$self->{'img_sizer'}->Add($this->{'img'},0,(wxALL) & (~wxLEFT) | wxALIGN_RIGHT, 8);
	$this->{'topsizer'}->Add($this->{'text_sizer'},1,wxALL, 20);
	$this->{'topsizer'}->Add($self->{'img_sizer'});
	$this->SetAutoLayout(1);
	my $toptopsizer = Wx::BoxSizer->new(wxVERTICAL);
	$toptopsizer->Add($this->{'topsizer'},1,wxEXPAND);
	my $line = Wx::Panel->new($this,-1,[0,0],[1,2]);
	$line->SetBackgroundColour(wxBLACK);
	$toptopsizer->Add($line,0,wxEXPAND);	
	$this->SetSizerAndFit($toptopsizer);
	$this->Layout;
	return $this;
}

sub AcceptsFocus{
	my ($self) = @_;
	return 0;
}

sub setTitle{
	my ($self,$text) = @_;
	$self->{'text_sizer'}->Remove($self->{'title'});
	$self->{'title'}->setText($text);
	$self->{'text_sizer'}->Prepend($self->{'title'},0);
	$self->Layout;
}

sub setSubTitle{
	my ($self,$text) = @_;
	$self->{'text_sizer'}->Remove($self->{'subtitle'});
	$self->{'subtitle'}->setText($text);
	$self->{'text_sizer'}->Add($self->{'subtitle'},0);
	$self->Layout;
}

sub Destroy{
	my ($self) = @_;
	delete $self->{'img_sizer'};
	$self->{'text_sizer'}->Remove($self->{'subtitle'});
	$self->{'text_sizer'}->Remove($self->{'title'});
	$self->{'title'}->Destroy;
	delete $self->{'title'};
	$self->{'subtitle'}->Destroy;
	delete $self->{'subtitle'};
    $self->{'img'}->Destroy;
	delete $self->{'img'};
	while($self->{'topsizer'}->Remove(0)){}
	while($self->GetSizer->Remove(0)){}
	delete $self->{'topsizer'};
	$self->SUPER::Destroy;
}

sub DESTROY{
	my ($self) = @_;
	print ">>>>>> destroying $self\n"
		if $SAPDB::Install::DEBUG::DESTRUCT;

}




1;

==> maxdb-all-linux-64bit-x86_64-7_6_03_15.tgz: SAPDB/Install/Window/Banner.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_03/b_15/sys/src/install/perl/SAPDB/Install/Window/Banner.pm#1 $
# $DateTime: 2008/01/18 16:05:39 $
# $Change: 173096 $
#
# Desc: start SAP DB installation/update/patch/instanceupgrade, called by SDBINST/SDBUPD


package SAPDB::Install::Window::Banner;


use Wx::Event qw(EVT_SET_FOCUS);
use Wx qw( wxHORIZONTAL wxVERTICAL wxEXPAND wxLEFT
		   wxRIGHT wxALL wxBLACK wxALIGN_RIGHT
		   wxWHITE wxDECORATIVE wxNORMAL wxBOLD wxBOTTOM);

use	SAPDB::Install::Resources;
use	SAPDB::Install::Control::StaticText;	

#
#	should be base of Wx::PlWindow,
#	but it cannot "AutoLayout"
#	as workarround use SAPDB::Install::Helpers::PassiveWin here
#

use base SAPDB::Install::Helpers::PassiveWin;

sub new{
	my($this ) = shift->SUPER::new(@_);
	$this->SetBackgroundColour(wxWHITE);
	$this->{'topsizer'} = Wx::BoxSizer->new(wxHORIZONTAL);
	$self->{'img_sizer'} = Wx::BoxSizer->new(wxVERTICAL);
	my $rc = SAPDB::Install::Resources->new('RESOURCES.TGZ');
	my $imgs = $rc->getImages('banner/MaxDB1.png');
	$this->{'img'} = Wx::StaticBitmap->new($this,-1,Wx::Bitmap->new($imgs->{'banner/MaxDB1.png'}));
	$this->{'text_sizer'} = Wx::BoxSizer->new(wxVERTICAL);
	$this->{'title'} = SAPDB::Install::Control::StaticText->new($this,-1);
	$this->{'title'}->{'font'} = Wx::Font->new(18,$^O =~ /mswin/i ? wxNORMAL : wxDECORATIVE, wxNORMAL, wxBOLD, 0 );
	$this->{'title'}->{'text_colour'} = Wx::Colour->new(100,100,100);
	$this->{'subtitle'} = SAPDB::Install::Control::StaticText->new($this,-1);
	$this->{'subtitle'}->{'font'} = Wx::Font->new(10,wxNORMAL, wxNORMAL, wxBOLD, 0 );
	$this->{'subtitle'}->{'text_colour'} = Wx::Colour->new(100,100,100);
	$this->{'text_sizer'}->Add($this->{'title'});
	$this->{'text_sizer'}->Add($this->{'subtitle'});
	$self->{'img_sizer'}->Add($this->{'img'},0,(wxALL) & (~wxLEFT) & (~wxBOTTOM) | wxALIGN_RIGHT, 20);
	$this->{'topsizer'}->Add($this->{'text_sizer'},1,wxALL, 20);
	$this->{'topsizer'}->Add($self->{'img_sizer'});
	$this->SetAutoLayout(1);
	my $toptopsizer = Wx::BoxSizer->new(wxVERTICAL);
	$toptopsizer->Add($this->{'topsizer'},1,wxEXPAND);
	my $line = Wx::Panel->new($this,-1,[0,0],[1,2]);
	$line->SetBackgroundColour(wxBLACK);
	$toptopsizer->Add($line,0,wxEXPAND);	
	$this->SetSizerAndFit($toptopsizer);
	$this->Layout;
	return $this;
}

sub AcceptsFocus{
	my ($self) = @_;
	return 0;
}

sub setTitle{
	my ($self,$text) = @_;
	$self->{'text_sizer'}->Remove($self->{'title'});
	$self->{'title'}->setText($text);
	$self->{'text_sizer'}->Prepend($self->{'title'},0);
	$self->Layout;
}

sub setSubTitle{
	my ($self,$text) = @_;
	$self->{'text_sizer'}->Remove($self->{'subtitle'});
	$self->{'subtitle'}->setText($text);
	$self->{'text_sizer'}->Add($self->{'subtitle'},0);
	$self->Layout;
}

sub Destroy{
	my ($self) = @_;
	delete $self->{'img_sizer'};
	$self->{'text_sizer'}->Remove($self->{'subtitle'});
	$self->{'text_sizer'}->Remove($self->{'title'});
	$self->{'title'}->Destroy;
	delete $self->{'title'};
	$self->{'subtitle'}->Destroy;
	delete $self->{'subtitle'};
    $self->{'img'}->Destroy;
	delete $self->{'img'};
	while($self->{'topsizer'}->Remove(0)){}
	while($self->GetSizer->Remove(0)){}
	delete $self->{'topsizer'};
	$self->SUPER::Destroy;
}

sub DESTROY{
	my ($self) = @_;
	print ">>>>>> destroying $self\n"
		if $SAPDB::Install::DEBUG::DESTRUCT;

}




1;
